.. image:: https://travis-ci.org/AllenInstitute/bigfeta.svg?branch=master
   :target: https://travis-ci.org/AllenInstitute/bigfeta
   :alt: Build Status
.. image:: https://codecov.io/gh/AllenInstitute/bigfeta/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/AllenInstitute/bigfeta
.. image:: https://readthedocs.org/projects/bigfeta/badge/?version=latest
  :target: https://bigfeta.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

BigFeta
#################

Global linear-least squares solution of transforms for alignment of features.

Level of support
################
We are planning on occasional updating this tool with no fixed schedule. Community involvement is encouraged through both issues and pull requests.

Documentation
#############
https://bigfeta.readthedocs.io/en/latest/index.html

Acknowledgement of Government Sponsorship
#########################################

Supported by the Intelligence Advanced Research Projects Activity (IARPA) via Department of Interior / Interior Business Center (DoI/IBC) contract number D16PC00004. The U.S. Government is authorized to reproduce and distribute reprints for Governmental purposes notwithstanding any copyright annotation thereon. Disclaimer: The views and conclusions contained herein are those of the authors and should not be interpreted as necessarily representing the official policies or endorsements, either expressed or implied, of IARPA, DoI/IBC, or the U.S. Government.


